@@ -3,7 +3,7 @@ package Specio::Exporter;
 use strict;
 use warnings;
 
-our $VERSION = '0.35';
+our $VERSION = '0.38';
 
 use parent 'Exporter';
 
@@ -61,7 +61,7 @@ Specio::Exporter - Base class for type libraries
 
 =head1 VERSION
 
-version 0.35
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -122,6 +122,22 @@ sub should return a I<list> of subroutines defined in your package that should
 also be exported. These subs will be exported unconditionally to any package
 that uses your package.
 
+=head1 COMBINING LIBRARIES WITH L<Specio::Subs>
+
+You can combine loading libraries with subroutine generation using
+L<Specio::Subs> by using C<_also_export> and
+C<Specio::Subs::subs_installed_into>:
+
+    package My::Library;
+
+    use My::Library::Internal -reexport;
+    use Specio::Library::Builtins -reexport;
+    use Specio::Subs qw( My::Library::Internal Specio::Library::Builtins );
+
+    sub _also_export {
+        return Specio::Subs::subs_installed_into(__PACKAGE__);
+    }
+
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
